/* Xiao -- An outliner library for GTK
 * Copyright (C) 2002 Gary Benson
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */
#ifndef __XIAO_HANDLE_H__
#define __XIAO_HANDLE_H__


#include <gdk/gdk.h>
#include <gtk/gtkwidget.h>


#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

#define XIAO_TYPE_HANDLE          (xiao_handle_get_type ())
#define XIAO_HANDLE(obj)          (GTK_CHECK_CAST (obj, XIAO_TYPE_HANDLE, XiaoHandle))
#define XIAO_HANDLE_CLASS(klass)  (GTK_CHECK_CLASS_CAST (klass, XIAO_TYPE_HANDLE, XiaoHandleClass))
#define XIAO_IS_HANDLE(obj)       (GTK_CHECK_TYPE (obj, XIAO_TYPE_HANDLE))


typedef struct _XiaoHandle       XiaoHandle;
typedef struct _XiaoHandleClass  XiaoHandleClass;

struct _XiaoHandle
{
    GtkWidget widget;

    gint width, height;

    guint folded : 1;
    guint selected : 1;
};

struct _XiaoHandleClass
{
    GtkWidgetClass parent_class;

    void (*fold_event)   (XiaoHandle *handle);
    void (*select_event) (XiaoHandle *handle);
};


GtkType        xiao_handle_get_type       (void);
GtkWidget*     xiao_handle_new            (void);
void           xiao_handle_set_folded     (XiaoHandle *handle,
					   gboolean    folded);
gboolean       xiao_handle_get_folded     (XiaoHandle *handle);
void           xiao_handle_set_selected   (XiaoHandle *handle,
					   gboolean    selected);
gboolean       xiao_handle_get_selected   (XiaoHandle *handle);

#ifdef __cplusplus
}
#endif /* __cplusplus */


#endif /* __XIAO_HANDLE_H__ */
