/* Xiao -- An outliner library for GTK
 * Copyright (C) 2002 Gary Benson
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */
#include "xiaoitem.h"
#include "xiaohandle.h"
#include "xiaogroup.h"
#include <gtk/gtkvbox.h>
#include <gtk/gtktextview.h>

static void
xiao_item_class_init(XiaoItemClass *class)
{
}

static void
xiao_item_init (XiaoItem *item)
{
    GtkWidget *vbox;

    /* left hand side contains the handle */
    vbox = gtk_vbox_new(FALSE, 0);
    gtk_box_pack_start(GTK_BOX(item), vbox, FALSE, FALSE, 0);

    item->handle = xiao_handle_new();
    gtk_box_pack_start(GTK_BOX(vbox), item->handle, FALSE, FALSE, 0);
    gtk_widget_show(item->handle);

    gtk_widget_show(vbox);
    
    /* right hand side contains the text and children */
    vbox = gtk_vbox_new(FALSE, 0);
    gtk_box_pack_start(GTK_BOX(item), vbox, FALSE, FALSE, 0);

    item->text = gtk_text_view_new();
    gtk_box_pack_start(GTK_BOX(vbox), item->text, FALSE, FALSE, 0);
    gtk_text_view_set_wrap_mode(GTK_TEXT_VIEW(item->text), GTK_WRAP_WORD);
    gtk_widget_show(item->text);

    item->children = xiao_group_new();
    gtk_box_pack_start(GTK_BOX(vbox), item->children, FALSE, FALSE, 0);
    gtk_widget_show(item->children);

    gtk_widget_show(vbox);
}

GType
xiao_item_get_type(void)
{
    static GType item_type = 0;

    if(!item_type) {
	static const GTypeInfo item_info =
	{
	    sizeof(XiaoItemClass),
	    NULL,
	    NULL,
	    (GClassInitFunc)xiao_item_class_init,
	    NULL,
	    NULL,
	    sizeof(XiaoItem),
	    0,
	    (GInstanceInitFunc)xiao_item_init,
	};

      item_type = g_type_register_static(
	  GTK_TYPE_HBOX, "XiaoItem", &item_info, 0);
    }

    return item_type;
}

GtkWidget*
xiao_item_new(const char *str)
{
    XiaoItem *item;
    
    item = XIAO_ITEM(g_object_new(xiao_item_get_type(), NULL));

    if (str && *str) {
	GtkTextBuffer *buffer;
	GtkTextIter iter;

	buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(item->text));
	gtk_text_buffer_get_iter_at_offset (buffer, &iter, 0);
	gtk_text_buffer_insert (buffer, &iter, str, -1);
    }

    return GTK_WIDGET(item);
}
